@@ -21,16 +21,9 @@ const (
 	KibanaName          = "kibana"
 	KibanaProxyName     = "kibana-proxy"
 	CuratorName         = "curator"
-	LogStoreService     = ElasticsearchFQDN + ":" + ElasticsearchPort
 	LogStoreURL         = "https://" + ElasticsearchFQDN + ":" + ElasticsearchPort
 	MasterCASecretName  = "master-certs"
-
-	InternalOutputName       = "clo-default-output-es"
-	CollectorSecretName      = "fluentd"
-	DefaultAppPipelineName   = "clo-default-app-pipeline"
-	DefaultInfraPipelineName = "clo-default-infra-pipeline"
-	/* #nosec - suppressing rule G101 */
-	KibanaSessionSecretName = "kibana-session-secret"
+	CollectorSecretName = "fluentd"
 )
 
 var ReconcileForGlobalProxyList = []string{FluentdTrustedCAName}
