@@ -6,7 +6,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	cl "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
-	k8shandler "github.com/openshift/cluster-logging-operator/pkg/k8shandler"
+	"github.com/openshift/cluster-logging-operator/pkg/logger"
 	elasticsearch "github.com/openshift/elasticsearch-operator/pkg/apis/logging/v1"
 )
 
@@ -19,6 +19,7 @@ const (
 )
 
 func NewClusterLogging(componentTypes ...LogComponentType) *cl.ClusterLogging {
+	logger.Debugf("NewClusterLogging %v", componentTypes)
 	instance := &cl.ClusterLogging{
 		TypeMeta: metav1.TypeMeta{
 			Kind:       "ClusterLogging",
@@ -27,9 +28,6 @@ func NewClusterLogging(componentTypes ...LogComponentType) *cl.ClusterLogging {
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      ClusterLoggingName,
 			Namespace: OpenshiftLoggingNS,
-			Annotations: map[string]string{
-				k8shandler.ForwardingAnnotation: "enabled",
-			},
 		},
 		Spec: cl.ClusterLoggingSpec{
 			ManagementState: cl.ManagementStateManaged,
